Enum gear_sandbox_interface::Instantiate

source ·
pub enum Instantiate {
    Version1,
    Version2,
}

Variants



Version1

The first version of instantiate method and syscalls.



Version2

The second version of syscalls changes their signatures to accept global gas value as its first argument and return the remaining gas value as its first result tuple element. The approach eliminates redundant host calls to get/set WASM-global value.